@@ -1,5 +1,5 @@
 /*  smplayer, GUI front-end for mplayer.
-    Copyright (C) 2006-2021 Ricardo Villalba <ricardo@smplayer.info>
+    Copyright (C) 2006-2023 Ricardo Villalba <ricardo@smplayer.info>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -51,6 +51,10 @@
 #include "myscroller.h"
 #endif
 
+#if QT_VERSION >= 0x060000
+#include <QMenu>
+#endif
+
 /*
 #include <QLineEdit>
 #include <QItemDelegate>
