@@ -1,5 +1,5 @@
 /*  smplayer, GUI front-end for mplayer.
-    Copyright (C) 2006-2020 Ricardo Villalba <rvm@users.sourceforge.net>
+    Copyright (C) 2006-2023 Ricardo Villalba <ricardo@smplayer.info>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -30,7 +30,7 @@ class QSettings;
 class Filter {
 public:
 	Filter() {};
-	Filter(QString tr_name, QString name, QString options = QString::null) { _tr_name = tr_name; _name = name; _options = options; };
+	Filter(QString tr_name, QString name, QString options = QString()) { _tr_name = tr_name; _name = name; _options = options; };
 
 	void setTrName(QString tr_name) { _tr_name = tr_name; };
 	void setName(QString name) { _name = name; };
