@@ -1,5 +1,5 @@
 /*  smplayer, GUI front-end for mplayer.
-    Copyright (C) 2006-2020 Ricardo Villalba <rvm@users.sourceforge.net>
+    Copyright (C) 2006-2023 Ricardo Villalba <ricardo@smplayer.info>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -30,7 +30,7 @@ class QSettings;
 class HDPISupport {
 
 public:
-	HDPISupport(const QString & config_path = QString::null);
+	HDPISupport(const QString & config_path = QString());
 	~HDPISupport();
 
 #ifdef HDPI_STORE_DATA
