@@ -350,4 +350,110 @@ QMap<QString,QString> Languages::enca() {
 	return l;
 }
 
+QMap<QString,QString> Languages::os_languages() {
+	QMap<QString,QString> l;
+	l["af"] = tr("Afrikaans");
+	l["be"] = tr("Belarusian");
+	l["my"] = tr("Burmese");
+	l["ab"] = tr("Abkhazian");
+	l["ar"] = tr("Arabic");
+	l["hy"] = tr("Armenian");
+	l["as"] = tr("Assamese");
+	l["at"] = tr("Asturian");
+	l["eu"] = tr("Basque");
+	l["bn"] = tr("Bengali");
+	l["br"] = tr("Breton");
+	l["bg"] = tr("Bulgarian");
+	l["ca"] = tr("Catalan");
+	l["zh-cn"] = tr("Chinese (simplified)");
+	l["fr"] = tr("French");
+	l["ka"] = tr("Georgian");
+	l["de"] = tr("German");
+	l["gd"] = tr("Gaelic");
+	l["ga"] = tr("Irish");
+	l["gl"] = tr("Galician");
+	l["el"] = tr("Greek");
+	l["he"] = tr("Hebrew");
+	l["hi"] = tr("Hindi");
+	l["hr"] = tr("Croatian");
+	l["hu"] = tr("Hungarian");
+	l["ig"] = tr("Igbo");
+	l["is"] = tr("Icelandic");
+	l["ia"] = tr("Interlingua");
+	l["kk"] = tr("Kazakh");
+	l["lv"] = tr("Latvian");
+	l["lt"] = tr("Lithuanian");
+	l["ml"] = tr("Malayalam");
+	l["it"] = tr("Italian");
+	l["ja"] = tr("Japanese");
+	l["km"] = tr("Khmer");
+	l["ko"] = tr("Korean");
+	l["ku"] = tr("Kurdish");
+	l["mk"] = tr("Macedonian");
+	l["mr"] = tr("Marathi");
+	l["nv"] = tr("Navajo");
+	l["no"] = tr("Norwegian");
+	l["oc"] = tr("Occitan");
+	l["fa"] = tr("Persian");
+	l["pl"] = tr("Polish");
+	l["pt-pt"] = tr("Portuguese");
+	l["ps"] = tr("Pushto");
+	l["ru"] = tr("Russian");
+	l["sr"] = tr("Serbian");
+	l["sk"] = tr("Slovak");
+	l["sl"] = tr("Slovenian");
+	l["sy"] = tr("Syriac");
+	l["ta"] = tr("Tamil");
+	l["me"] = tr("Montenegrin");
+	l["ze"] = tr("Chinese bilingual");
+	l["sd"] = tr("Sindhi");
+	l["es"] = tr("Spanish");
+	l["sw"] = tr("Swahili");
+	l["sv"] = tr("Swedish");
+	l["tt"] = tr("Tatar");
+	l["te"] = tr("Telugu");
+	l["th"] = tr("Thai");
+	l["tk"] = tr("Turkmen");
+	l["tr"] = tr("Turkish");
+	l["uk"] = tr("Ukrainian");
+	l["uz"] = tr("Uzbek");
+	l["vi"] = tr("Vietnamese");
+	l["cy"] = tr("Welsh");
+	l["ro"] = tr("Romanian");
+	l["pt-br"] = tr("Portuguese (BR)");
+	l["zh-tw"] = tr("Chinese (traditional)");
+	l["sq"] = tr("Albanian");
+	l["an"] = tr("Aragonese");
+	l["az"] = tr("Azerbaijani");
+	l["bs"] = tr("Bosnian");
+	l["cs"] = tr("Czech");
+	l["da"] = tr("Danish");
+	l["nl"] = tr("Dutch");
+	l["en"] = tr("English");
+	l["eo"] = tr("Esperanto");
+	l["et"] = tr("Estonian");
+	l["fi"] = tr("Finnish");
+	l["id"] = tr("Indonesian");
+	l["kn"] = tr("Kannada");
+	l["lb"] = tr("Luxembourgish");
+	l["ms"] = tr("Malay");
+	l["ma"] = tr("Manipuri");
+	l["mn"] = tr("Mongolian");
+	l["ne"] = tr("Nepali");
+	l["or"] = tr("Odia");
+	l["si"] = tr("Sinhalese");
+	l["se"] = tr("Northern Sami");
+	l["so"] = tr("Somali");
+	l["tl"] = tr("Tagalog");
+	l["ur"] = tr("Urdu");
+	l["pm"] = tr("Portuguese (MZ)");
+	l["ea"] = tr("Spanish (LA)");
+	l["ex"] = tr("Extremaduran");
+	l["pr"] = tr("Dari");
+	l["sp"] = tr("Spanish (EU)");
+	l["sx"] = tr("Santali");
+	l["tp"] = tr("Toki Pona");
+	return l;
+}
+
 #include "moc_languages.cpp"
