@@ -1,5 +1,5 @@
 /*  smplayer, GUI front-end for mplayer.
-    Copyright (C) 2006-2020 Ricardo Villalba <rvm@users.sourceforge.net>
+    Copyright (C) 2006-2023 Ricardo Villalba <ricardo@smplayer.info>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -36,7 +36,7 @@ LogWindow::LogWindow( QWidget* parent )
 {
 	setupUi(this);
 
-	browser->setFont( QFont("fixed") );
+	browser->setFont( QFont("courier") );
 
 #if QT_VERSION >= 0x050000
 	MyScroller::setScroller(browser);
