@@ -1,5 +1,5 @@
 /*  smplayer, GUI front-end for mplayer.
-    Copyright (C) 2006-2021 Ricardo Villalba <ricardo@smplayer.info>
+    Copyright (C) 2006-2023 Ricardo Villalba <ricardo@smplayer.info>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -24,7 +24,9 @@
 #include "mediadata.h"
 #include "config.h"
 
+#if QT_VERSION < 0x060000
 class QStringList;
+#endif
 
 class MplayerProcess : public PlayerProcess
 {
@@ -38,7 +40,8 @@ public:
 
 	// Command line options
 	void setMedia(const QString & media, bool is_playlist = false);
-	void setFixedOptions();
+	void setPredefinedOptions();
+	void disableConfig();
 	void disableInput();
 	void setOption(const QString & option_name, const QVariant & value = QVariant());
 	void addUserOption(const QString & option);
