@@ -1,5 +1,5 @@
 /*  smplayer, GUI front-end for mplayer.
-    Copyright (C) 2006-2021 Ricardo Villalba <ricardo@smplayer.info>
+    Copyright (C) 2006-2023 Ricardo Villalba <ricardo@smplayer.info>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -73,13 +73,15 @@ void MPVProcess::setMedia(const QString & media, bool is_playlist) {
 			"INFO_VIDEO_FPS=${=container-fps:${=fps}}\n"
 //			"INFO_VIDEO_BITRATE=${=video-bitrate}\n"
 			"INFO_VIDEO_FORMAT=${=video-format}\n"
-			"INFO_VIDEO_CODEC=${=video-codec}\n"
+//			"INFO_VIDEO_CODEC=${=video-codec}\n"
+			"INFO_VIDEO_CODEC=${=video-format}\n"
 			"INFO_DEMUX_ROTATION=${=track-list/0/demux-rotation}\n"
 
 //			"INFO_AUDIO_BITRATE=${=audio-bitrate}\n"
 //			"INFO_AUDIO_FORMAT=${=audio-format}\n" // old
 			"INFO_AUDIO_FORMAT=${=audio-codec-name}\n"
-			"INFO_AUDIO_CODEC=${=audio-codec}\n"
+//			"INFO_AUDIO_CODEC=${=audio-codec}\n"
+			"INFO_AUDIO_CODEC=${=audio-codec-name}\n"
 //			"INFO_AUDIO_RATE=${=audio-samplerate}\n" // old
 			"INFO_AUDIO_RATE=${=audio-params/samplerate}\n"
 //			"INFO_AUDIO_NCH=${=audio-channels}\n" // old
@@ -848,6 +850,10 @@ void MPVProcess::mute(bool b) {
 
 void MPVProcess::setPause(bool b) {
 	sendCommand(QString("set pause %1").arg(b ? "yes" : "no"));
+
+	// Workaround for mpv 0.37, playback not resuming after pause
+	// It seems mpv reports the pause state in the status line with some delay
+	if (b) sendCommand("no-osd seek 0 relative exact");
 }
 
 void MPVProcess::frameStep() {
@@ -890,8 +896,10 @@ void MPVProcess::showTimeOnOSD() {
 #ifdef OSD_WITH_TIMER
 void MPVProcess::toggleInfoOnOSD() {
 	#ifdef USE_MPV_STATS
-	stats_page++;
-	if (stats_page > 3) stats_page = 0;
+	if (stats_page == 0 || osd_timer->isActive()) {
+		stats_page++;
+		if (stats_page > 3) stats_page = 0;
+	}
 
 	if (stats_page > 0) {
 		if (!osd_timer->isActive()) osd_timer->start();
