@@ -399,6 +399,15 @@ void Playlist::updateWindowTitle() {
 	if (title.isEmpty()) title = tr("Untitled playlist");
 	if (modified) title += " (*)";
 
+	if (automatically_get_info) {
+		int total_duration = 0;
+		for (int n = 0; n < count(); n++) {
+			PLItem * i = itemData(n);
+			total_duration += i->duration();
+		}
+		title += " [" + Helper::formatTime(total_duration) + "]";
+	}
+
 	qDebug() << "Playlist::updateWindowTitle:" << title;
 
 	setWindowTitle(title);
@@ -486,6 +495,9 @@ void Playlist::createTable() {
 	connect(listView, SIGNAL(activated(const QModelIndex &)),
             this, SLOT(itemActivated(const QModelIndex &)) );
 
+	connect(listView->horizontalHeader(), SIGNAL(sectionClicked(int)),
+            this, SLOT(headerClicked(int)));
+
 	setFilenameColumnVisible(false);
 	setShuffleColumnVisible(false);
 }
@@ -1400,7 +1412,7 @@ void Playlist::load() {
 				loadXSPF(s);
 			}
 			else
-			if (suffix == "m3u") {
+			if (suffix == "m3u" || suffix == "m3u8") {
 				load_m3u(s);
 			}
 			else {
@@ -2587,6 +2599,11 @@ int Playlist::maxItemsUrlHistory() {
 }
 #endif
 
+void Playlist::headerClicked(int index) {
+	qDebug() << "Playlist::headerClicked:" << index;
+	shuffleAct->setChecked(false);
+}
+
 // Language change stuff
 void Playlist::changeEvent(QEvent *e) {
 	if (e->type() == QEvent::LanguageChange) {
