@@ -1,5 +1,5 @@
 /*  smplayer, GUI front-end for mplayer.
-    Copyright (C) 2006-2021 Ricardo Villalba <ricardo@smplayer.info>
+    Copyright (C) 2006-2023 Ricardo Villalba <ricardo@smplayer.info>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -149,6 +149,10 @@ public:
 	bool global_audio_equalizer;
 	AudioEqualizerList audio_equalizer;
 
+	// Global speed
+	bool global_speed;
+	double speed;
+
 	bool autosync;
 	int autosync_factor;
 
@@ -367,6 +371,8 @@ public:
 
 	bool use_native_open_dialog;
 
+	bool disable_player_config;
+
 
 	/* *********
 	   GUI stuff
