@@ -1,5 +1,5 @@
 /*  smplayer, GUI front-end for mplayer.
-    Copyright (C) 2006-2021 Ricardo Villalba <ricardo@smplayer.info>
+    Copyright (C) 2006-2023 Ricardo Villalba <ricardo@smplayer.info>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -341,6 +341,8 @@ void PrefGeneral::setData(Preferences * pref) {
 #endif
 	updateDriverCombos();
 #endif // AUDIO_DEVICES_SELECTION
+
+	global_speed_check->setChecked(pref->global_speed);
 }
 
 void PrefGeneral::getData(Preferences * pref) {
@@ -471,6 +473,8 @@ void PrefGeneral::getData(Preferences * pref) {
 
 	TEST_AND_SET(pref->use_mc, mcActivated());
 	TEST_AND_SET(pref->mc_value, mc());
+
+	pref->global_speed = global_speed_check->isChecked();
 }
 
 void PrefGeneral::updateDriverCombos() {
@@ -1019,7 +1023,7 @@ void PrefGeneral::player_combo_changed(int idx) {
 	}
 
 	#ifdef OS_UNIX_NOT_MAC
-	wayland_check->setVisible(mplayerPath().contains("mpv"));
+	//wayland_check->setVisible(mplayerPath().contains("mpv"));
 	#endif
 }
 #endif
@@ -1141,6 +1145,10 @@ void PrefGeneral::createHelp() {
 		);
 #endif
 
+	setWhatsThis(global_speed_check, tr("Keep selected speed across files"),
+		tr("If this option is enabled, the speed selected in the Play menu will be applied for all files.") +" "+
+		tr("Otherwise each file will use its own speed setting."));
+
 	setWhatsThis(pause_if_hidden_check, tr("Pause when minimized"),
 		tr("If this option is enabled, the file will be paused when the "
            "main window is hidden. When the window is restored, playback "
