@@ -1,5 +1,5 @@
 /*  smplayer, GUI front-end for mplayer.
-    Copyright (C) 2006-2020 Ricardo Villalba <rvm@users.sourceforge.net>
+    Copyright (C) 2006-2023 Ricardo Villalba <ricardo@smplayer.info>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -374,7 +374,7 @@ void PrefSubtitles::on_windowsfontdir_check_toggled(bool b) {
 	qDebug("PrefSubtitles::on_windowsfontdir_check_toggled: %d", b);
 
 	if (b) {
-		style_font_combo->setFontsFromDir(QString::null);
+		style_font_combo->setFontsFromDir(QString());
 	} else {
 		QString fontdir = Paths::fontPath();
 		//QString fontdir = "/tmp/fonts/";
