@@ -1,5 +1,5 @@
 /*  smplayer, GUI front-end for mplayer.
-    Copyright (C) 2006-2020 Ricardo Villalba <rvm@users.sourceforge.net>
+    Copyright (C) 2006-2023 Ricardo Villalba <ricardo@smplayer.info>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -28,7 +28,7 @@ class QRCodeLabel : public QFrame
 	Q_OBJECT
 
 public:
-	QRCodeLabel(QWidget * parent = 0, Qt::WindowFlags f = 0);
+	QRCodeLabel(QWidget * parent = 0, Qt::WindowFlags f = QFlag(0));
 	~QRCodeLabel();
 
 	QString text() { return qrcode_text; };
