@@ -1,5 +1,5 @@
 /*  smplayer, GUI front-end for mplayer.
-    Copyright (C) 2006-2021 Ricardo Villalba <ricardo@smplayer.info>
+    Copyright (C) 2006-2023 Ricardo Villalba <ricardo@smplayer.info>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -205,6 +205,8 @@ void CodeDownloader::askAndDownload(QWidget * parent, ErrorMessage e, const QStr
 	if (app_basename == "yt-dlp") {
 		#ifdef Q_OS_MACX
 		url = "https://github.com/yt-dlp/yt-dlp/releases/latest/download/yt-dlp_macos";
+		#elif defined(Q_OS_LINUX)
+		url = "https://github.com/yt-dlp/yt-dlp/releases/latest/download/yt-dlp_linux";
 		#else
 		url = "https://github.com/yt-dlp/yt-dlp/releases/latest/download/yt-dlp";
 		#endif
